@@ -14,12 +14,14 @@ def _template_from_file(filename, context):
 
 def get_sketch_index_content(sketch):
     """
-    Renders SKETCH_NAME/index.html to display the sketch visualization
+    Renders SKETCH_NAME/index.html to display the sketch visualization.
+    template can be a pathlib.Path object with a specified custom template path
     """
     context = {
         "sketch_name": sketch.sketch_name,
         "p5_js_url": sketch.urls.p5_js_url,
         "sketch_js_url":  sketch.urls.sketch_js_url,
+        "sketch_content": sketch.sketch_content,
     }
     template_file = sketch.config.get_index_template()
     return _template_from_file(template_file, context)
@@ -29,12 +31,9 @@ def get_target_sketch_content(sketch):
     """
     Renders the content to be written in the temporary SKETCH_NAME/target_sketch.py file
     """
-    with sketch.sketch_py.open() as fd:
-        content = fd.read()
-
     context = {
         "sketch_name": sketch.sketch_name,
-        "sketch_content": content,
+        "sketch_content": sketch.sketch_content,
     }
     target_js_file = sketch.config.get_target_js_template()
     return _template_from_file(target_js_file, context)
